<?php

namespace Laraautos\Dealer\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Laraautos\Dealer\Models\Dealer;

class DealerPolicy
{

    /**
     * Determine if the given user can view the dealer.
     *
     * @param UserPolicyInterface $authUser
     * @param Dealer $dealer
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Dealer $dealer)
    {
        if ($authUser->canDo('dealer.dealer.view') && $authUser->isAdmin()) {
            return true;
        }

        return $dealer->user_id == user_id() && $dealer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a dealer.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('dealer.dealer.create');
    }

    /**
     * Determine if the given user can update the given dealer.
     *
     * @param UserPolicyInterface $authUser
     * @param Dealer $dealer
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Dealer $dealer)
    {
        if ($authUser->canDo('dealer.dealer.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $dealer->user_id == user_id() && $dealer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given dealer.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Dealer $dealer)
    {
        return $dealer->user_id == user_id() && $dealer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given dealer.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Dealer $dealer)
    {
        if ($authUser->canDo('dealer.dealer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given dealer.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Dealer $dealer)
    {
        if ($authUser->canDo('dealer.dealer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
