<?php

namespace Laraautos\Dealer\Providers;

use Illuminate\Support\ServiceProvider;
use Laraautos\Dealer\Dealer;

class DealerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'dealer');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'dealer');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Laraautos\Dealer\Providers\AuthServiceProvider::class);
        $this->app->register(\Laraautos\Dealer\Providers\RouteServiceProvider::class);
        // $this->app->register(\Laraautos\Dealer\Providers\EventServiceProvider::class);
        // $this->app->register(\Laraautos\Dealer\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('laraautos.dealer', function($app)
        {
            return $this->app->make(Dealer::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind Dealer to repository
        $this->app->bind(
            'Laraautos\Dealer\Interfaces\DealerRepositoryInterface',
            \Laraautos\Dealer\Repositories\Eloquent\DealerRepository::class
        );
    }


    /**
     * Merges user's and dealer's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'laraautos.dealer'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Laraautos\Dealer\Commands\Dealer::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['laraautos.dealer'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('laraautos/dealer.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/dealer')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/dealer')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
